VariableRangeCheckerChip

Struct VariableRangeCheckerChip 

pub struct VariableRangeCheckerChip {
    pub air: VariableRangeCheckerAir,
    pub count: Vec<AtomicU32>,
}

Fields

air: VariableRangeCheckerAircount: Vec<AtomicU32>

Implementations

Source

impl VariableRangeCheckerChip

pub fn new(bus: VariableRangeCheckerBus) -> Self

pub fn bus(&self) -> VariableRangeCheckerBus

pub fn range_max_bits(&self) -> usize

pub fn air_width(&self) -> usize

pub fn add_count(&self, value: u32, max_bits: usize)

pub fn clear(&self)

pub fn generate_trace<F: Field>(&self) -> RowMajorMatrix<F>

Generates trace and resets the internal counters all to 0.

pub fn decompose<F: Field>(&self, value: u32, bits: usize, limbs: &mut [F])

Range checks that value is bits bits by decomposing into limbs where all but last limb is range_max_bits bits. Assumes there are enough limbs.